|pypi| |travis-ci| |cc-grade| |cc-issues| |coverage|

=======
bericht
=======

PDF generator with html/css and supporting infinite filesize.

.. code-block:: python

    from bericht import HTML

you should find a `test.pdf` file in the location where you started python

.. |pypi| image:: https://badge.fury.io/py/bericht.svg
   :target: https://pypi.python.org/pypi/bericht
   :alt: Package

.. |travis-ci| image:: https://travis-ci.org/systori/bericht.svg?branch=master
   :target: https://travis-ci.org/systori/bericht
   :alt: Build

.. |cc-grade| image:: https://codeclimate.com/github/systori/bericht/badges/gpa.svg
   :target: https://codeclimate.com/github/systori/bericht
   :alt: Code Climate

.. |cc-issues| image:: https://codeclimate.com/github/systori/bericht/badges/issue_count.svg
   :target: https://codeclimate.com/github/systori/bericht
   :alt: Issue Count

.. |coverage| image:: https://codeclimate.com/github/systori/bericht/badges/coverage.svg
   :target: https://codeclimate.com/github/systori/bericht/coverage
   :alt: Test Coverage
